@@ -8,16 +8,17 @@ my $db = DBI->connect("DBI:SQLite:dbname=testdb","","");
 my $ldap = Net::LDAP->new("127.0.0.1");
 
 my $result = $ldap->bind(dn=>"cn=Manager,dc=g0n,dc=net",
-			password=>"XXXXX");
+			password=>"XXXX");
 if ($result->code){die $result->error}
 
 
 use Data::Sync;
 my $logfile;
 open ($logfile,">","logfile.txt");
-my $synchandle = Data::Sync->new(log=>"STDOUT");
+my $synchandle = Data::Sync->new(log=>$logfile);
 
-$synchandle->source($db,{select=>"select name,postal,telephone from target"});
+$synchandle->source($db,{select=>"select name,postal,telephone from target",
+			batchsize=>5});
 
 			
 $synchandle->target($ldap);
@@ -31,4 +32,4 @@ $synchandle->buildattributes(dn=>"cn=%NAME%,ou=testcontainer,dc=g0n,dc=net",
 
 $synchandle->transforms(telephoneNumber=>'s/^(\d) (\d\d\d)/$2 $1/ ');
 print  $synchandle->run;
-
+print $synchandle->error."\n";
